tower

package module
v0.0.0-...-8200b3f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 18, 2022 License: MIT Imports: 0 Imported by: 0

README

logo

Tower: Pure Functional Programming in Go

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Filter

func Filter[A any](fn func(A) bool, a []A) []A

func Map

func Map[A, B any](a []A, fn func(A) B) []B

Map takes a slice generic type A, a function to move from type A to type B where A and B can be different types and returns a slice of type B.

Usage: Map([]int{1,2,3},)

Types

This section is empty.

Jump to