package
module
Version:
v0.0.0-...-8200b3f
Opens a new window with list of versions in this module.
Published: Mar 18, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶

Tower: Pure Functional Programming in Go
Documentation
¶
func Filter[A any](fn func(A) bool, a []A) []A
func Map[A, B any](a []A, fn func(A) B) []B
Map takes a slice generic type A, a function to move from type A to type B
where A and B can be different types
and returns a slice of type B.
Usage:
Map([]int{1,2,3},)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.